@@ -189,4 +189,9 @@ extern char *crypt(); /* libufc */
 # define USE_SGTTY
 #endif
 
+#ifdef USE_DMALLOC
+# include <dmalloc.h>
+#endif
+
 #endif /* IDEFINES_H */
+
