@@ -19,7 +19,7 @@
  */
 
 
-/* $Id: mcrypt.c,v 1.13 2001/09/15 09:41:37 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.14 2001/09/24 14:11:10 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -37,7 +37,7 @@
 #include <popen.h>
 
 static char rcsid[] =
-    "$Id: mcrypt.c,v 1.13 2001/09/15 09:41:37 nmav Exp $";
+    "$Id: mcrypt.c,v 1.14 2001/09/24 14:11:10 nmav Exp $";
 
 char tmperr[128];
 unsigned int stream_flag = FALSE;
@@ -445,16 +445,23 @@ int main(int argc, char **argv)
 
 		siz = mcrypt_module_get_algo_supported_key_sizes( algorithm, algorithms_directory, &i);
 		x=0;
-		for (y=0;y<i;y++) {
-			if (siz[y]==info.keysize) {
-				x=1;
-				break;
+		if (siz==NULL || i == 0) x = 1; /* we have already checked if it is
+				       * less than the maximum supported
+				       * by the algorithm
+				       */
+		else {
+			for (y=0;y<i;y++) {
+				if (siz[y]==info.keysize) {
+					x=1;
+					break;
+				}
 			}
+			free(siz);
 		}
+			
 		if (x==0) {
 			err_quit(_("The specified key size not valid for this algorithm.\n"));
 		}
-		free(siz);
 
 	}
 
